CaptureVisionManager class

CaptureVisionManager class.

Constructors

CaptureVisionManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
modelName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

init(String key) → Future<int>
Returns 0 if successful.
loadModel(ModelType modelType) → Future<int?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recognizeBuffer(Uint8List bytes, int width, int height, int stride, int format, int rotation) → Future<List<List<OcrLine>>?>
MRZ detection. bytes - image buffer. Returns a List of List<OcrLine>.
recognizeFile(String file) → Future<List<List<OcrLine>>?>
MRZ detection. file - path to the file. Returns a List of List<OcrLine>.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited