CaptureVisionRouter class

Constructors

CaptureVisionRouter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture(dynamic data, String template) → PromiseJsImpl<CapturedResult>
Recognize MRZ/VIN from a source.
initSettings(String settings) → PromiseJsImpl<void>
Initializes runtime settings from a JSON string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createInstance() → PromiseJsImpl<CaptureVisionRouter>
Creates a new instance of CaptureVisionRouter.