CapturedItem class

Constructors

CapturedItem()

Properties

angle → int
no setter
bytes → Uint8List
no setter
confidence → int
no setter
formatString → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
location → Location
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
no setter
type → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited