MRZ class

Constructors

MRZ()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseThreeLines(String line1, String line2, String line3) → MrzResult
Parse three lines of MRZ string.
parseTwoLines(String line1, String line2) → MrzResult
Parse two lines of MRZ string.