OcrLine class

OcrLine class.

Constructors

OcrLine()

Properties

confidence ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mrzResult ↔ MrzResult?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair
vinResult ↔ VinResult?
getter/setter pair
x1 ↔ int
getter/setter pair
x2 ↔ int
getter/setter pair
x3 ↔ int
getter/setter pair
x4 ↔ int
getter/setter pair
y1 ↔ int
getter/setter pair
y2 ↔ int
getter/setter pair
y3 ↔ int
getter/setter pair
y4 ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited